aboutsummaryrefslogtreecommitdiff
path: root/gdb/monitor.h
diff options
context:
space:
mode:
authorStu Grossman <grossman@cygnus>1995-03-25 00:36:01 +0000
committerStu Grossman <grossman@cygnus>1995-03-25 00:36:01 +0000
commita25a9f49ca74743dc2210e1f4f7f401098d94134 (patch)
tree32b258ffc038d1dce5dcec6ccc75481520e21faa /gdb/monitor.h
parent1ef0c066d9137e86018ddf1528e0210b176fd09a (diff)
downloadfsf-binutils-gdb-a25a9f49ca74743dc2210e1f4f7f401098d94134.zip
fsf-binutils-gdb-a25a9f49ca74743dc2210e1f4f7f401098d94134.tar.gz
fsf-binutils-gdb-a25a9f49ca74743dc2210e1f4f7f401098d94134.tar.bz2
* configure.in: Move test for m68*-est-* before m68*-*-coff*.
* findvar.c: Move default def of CANNOT_STORE_REGISTER closer to the beginning of the code. * (write_register_gen): New routine. Analogous to read_register_gen. * (write_register_bytes): Another rewrite! Make it smarter about not updating regs with the same value. * monitor.c (printf_monitor readchar): Use stderr instead of stdout to output debug info. Also cleanup readchar a little. * (expect): Make sure that excessive responses are null terminated. * (monitor_open): Check for magic number in monitor_ops struct. Allow multiple commands as init strings. Also, clear all breakpoints. * (monitor_resume monitor_wait): Send a command to dump all the regs for those targets which don't do so when waking up after a continue command. * (monitor_wait): Handle excessive response output better. * (monitor_write_memory): Use block fill, word, and long word commands (if they exist) to write memory more efficiently. * General cleanups to use flag bits instead of individual flag words in monitor_ops struct. * (monitor_command): Return output from command. * (monitor_load_srec): Allocate buffer only once. Use alloca. Wait for load response string instead of using a timeout to start sending S-records. Fix bug where value of srec_frame shrinks. If hashmark is set, print `-' for retransmissions. General cleanups. * (monitor_make_srec): Get rid of S-record default type kludge. * monitor.h: Use seperate struct for memory and register read/write commands. Memory commands can come in byte, word, long, and longlong forms. * (monitor_ops): Change lots of fields. Generalize some stuff. Put all flags into flags word. Allow init to be a list of commands. Add command for clearing all breakpoints, block fill, dumping all registers. * remote-est.c: Rewrite to use new monitor conventions. * config/m68k/est.mt (TDEPFILES): Add monitor.o. * config/m68k/tm-est.h: Set NUM_REGS to 18. * testsuite/gdb.base/break.exp: Lots of cleanups. Use gdb_test more thoroughly.
Diffstat (limited to 'gdb/monitor.h')
-rw-r--r--gdb/monitor.h86
1 files changed, 56 insertions, 30 deletions
diff --git a/gdb/monitor.h b/gdb/monitor.h
index 59b6691..a9b665b 100644
--- a/gdb/monitor.h
+++ b/gdb/monitor.h
@@ -56,57 +56,84 @@ struct rom_cmd_data {
ignored if TERM is NULL.
*/
-struct cmd_resp {
- char *cmd; /* Command to send */
+struct memrw_cmd
+{
+ char *cmdb; /* Command to send for byte read/write */
+ char *cmdw; /* Command for word (16 bit) read/write */
+ char *cmdl; /* Command for long (32 bit) read/write */
+ char *cmdll; /* Command for long long (64 bit) read/write */
char *resp_delim; /* String just prior to the desired value */
char *term; /* Terminating string to search for */
char *term_cmd; /* String to get out of sub-mode (if necessary) */
};
-struct monitor_ops {
- int type; /* 1 is ascii, 0 is GDB remote protocol */
- char *init; /* initialize to the monitor */
- char *execute; /* execute or usually GO command */
- char *resume; /* continue command */
- char *step; /* single step */
- char *set_break; /* set a breakpoint */
- char *clr_break; /* clear a breakpoint */
- int clr_type; /* number or address for clearing */
- struct cmd_resp setmem; /* set memory to a value */
- struct cmd_resp getmem; /* display memory */
- struct cmd_resp setreg; /* set a register */
- struct cmd_resp getreg; /* get a register */
+struct regrw_cmd
+{
+ char *cmd; /* Command to send for reg read/write */
+ char *resp_delim; /* String just prior to the desired value */
+ char *term; /* Terminating string to search for */
+ char *term_cmd; /* String to get out of sub-mode (if necessary) */
+};
+
+struct monitor_ops
+{
+ int flags; /* See below */
+ char **init; /* List of init commands. NULL terminated. */
+ char *cont; /* continue command */
+ char *step; /* single step */
+ char *set_break; /* set a breakpoint */
+ char *clr_break; /* clear a breakpoint */
+ char *clr_all_break; /* Clear all breakpoints */
+ char *fill; /* Memory fill cmd (addr len val) */
+ struct memrw_cmd setmem; /* set memory to a value */
+ struct memrw_cmd getmem; /* display memory */
+ struct regrw_cmd setreg; /* set a register */
+ struct regrw_cmd getreg; /* get a register */
/* Some commands can dump a bunch of registers
at once. This comes as a set of REG=VAL
pairs. This should be called for each pair
of registers that we can parse to supply
GDB with the value of a register. */
+ char *dump_registers; /* Command to dump all regs at once */
char *register_pattern; /* Pattern that picks out register from reg dump */
- void (*supply_register) PARAMS ((char *name, int namelen, char *val, int vallen));
- char *load; /* load command */
- char *prompt; /* monitor command prompt */
- char *cmd_delim; /* end-of-command delimitor */
- char *cmd_end; /* optional command terminator */
+ void (*supply_register) PARAMS ((char *name, int namelen, char *val, int vallen));
+ char *load; /* load command */
+ char *loadresp; /* Response to load command */
+ char *prompt; /* monitor command prompt */
+ char *cmd_delim; /* end-of-command delimitor */
+ char *cmd_end; /* optional command terminator */
struct target_ops *target; /* target operations */
- char **loadtypes; /* the load types that are supported */
- char **loadprotos; /* the load protocols that are supported */
- char *baudrates; /* supported baud rates */
- int stopbits; /* number of stop bits */
- char **regnames; /* array of register names in ascii */
+ char **loadtypes; /* the load types that are supported */
+ char **loadprotos; /* the load protocols that are supported */
+ char *baudrates; /* supported baud rates */
+ int stopbits; /* number of stop bits */
+ char **regnames; /* array of register names in ascii */
+ int magic; /* Check value */
};
+#define MONITOR_OPS_MAGIC 600925
+
+/* Flag defintions */
+
+#define MO_CLR_BREAK_USES_ADDR 0x1 /* If set, then clear breakpoint command
+ uses address, otherwise it uses an index
+ returned by the monitor. */
+#define MO_FILL_USES_ADDR 0x2 /* If set, then memory fill command uses
+ STARTADDR, ENDADDR+1, VALUE as args, else it
+ uses STARTADDR, LENGTH, VALUE as args. */
+#define MO_NEED_REGDUMP_AFTER_CONT 0x4 /* If set, then monitor doesn't auto-
+ matically supply register dump when
+ coming back after a continue. */
+
extern struct monitor_ops *current_monitor;
-#define PROTO_TYPE (current_monitor->type)
#define LOADTYPES (current_monitor->loadtypes)
#define LOADPROTOS (current_monitor->loadprotos)
#define INIT_CMD (current_monitor->init)
-#define GO_CMD (current_monitor->execute)
-#define CONT_CMD (current_monitor->resume)
+#define CONT_CMD (current_monitor->cont)
#define STEP_CMD (current_monitor->step)
#define SET_BREAK_CMD (current_monitor->set_break)
#define CLR_BREAK_CMD (current_monitor->clr_break)
-#define CLR_BREAK_ADDR (current_monitor->clr_type)
#define SET_MEM (current_monitor->setmem)
#define GET_MEM (current_monitor->getmem)
#define LOAD_CMD (current_monitor->load)
@@ -127,7 +154,6 @@ extern struct monitor_ops *current_monitor;
#define push_monitor(x) current_monitor = x;
#define SREC_SIZE 160
-#define GDBPROTO ((current_monitor->type) ? 0: 1)
/*
* FIXME: These are to temporarily maintain compatability with the